@@ -5,11 +5,10 @@ from datetime import timedelta
 from select import select
 from typing import Optional, Union
 
+__all__ = []
+
 
 def poll_fd(fd: int, timeout: Optional[Union[timedelta, float]] = None) -> bool:
-    if timeout is None:
-        timeout = 0.0
-
     if isinstance(timeout, timedelta):
         sec = timeout.total_seconds()
     else:
